==> chromatose-0.0.1.tar.gz: chromatose-0.0.1/chromatose/palettes.py <==
__version__ = "0.0.1"


selah = ['#405950',
         '#3e242f',
         '#7d4246',
         '#e06865',
         '#f3ad78']

frieda = ['#e6472c',
           '#eed9a1',
           '#93b8b2',
           '#3d2314',
           '#ecd8ae',
           '#35443c']

honeycombe = ['#ce554e',
            '#e29f2d',
            '#a6a78c',
            '#40312b',
            '#e5c794',]

crepuscule = ['#3c8588',
             '#4d3d31',
             '#c5572e',
             '#dbad4e',
             '#efedce',]

juniper = ['#b1516a',
            '#af9c85',
            '#bbc9a2',
            '#ebd5a2',
            '#595353']

plath = ['#30343f',
           '#a84b43',
           '#d6b7b5',
           '#30343f']

blonde = ['#edb1a3',
          '#d6543a',
          '#c4bae2',
          '#3c4ebf',
          '#40ada6',
          '#e3a600']

leather = ["#d3772b",
            "#f9edcc", 
            "#c32307", 
            "#483d8b", 
            "#7d939a",
          ]

gucci = ['#e8b789', 
         '#046a50', 
         '#ddb65f', 
         '#26183a', 
         '#e81f05']


sandbar = ['#000000', 
         '#a1d9da', 
         '#d1923f', 
         '#025e8f', 
         '#e9c5a5']

fiestaware = ['#ab0b11', 
              '#e27a00', 
              '#36a3c2', 
              '#dfcd00', 
              '#5a006e']


chilaquiles = ['#749e81', 
               '#821b07', 
               '#01300d', 
               '#d3af03']

eleven = ['#c65f25', 
          '#4c0c0a', 
          '#fc5659', 
          '#efb36e', 
          '#6487cc']

splenda = ['#6487cc', 
           '#d49a8e', 
           '#c0c7f6', 
           '#e396bd']


gremlin = ['#3a5b84', 
           '#9d2020', 
           '#2b2b2b', 
           '#836a00', 
           '#002c59']

pollen = ["#fB9e91",
          "#461a84",
          "#f5f0e3",
          "#b4b6d8",
          '#ffd082',
#         '#9dab86',
         ]

medium = ['#e3a201', 
          '#6762ab', 
          '#d55101', 
          '#0d936a']

juniper = [ "#216583",
            '#6C567B',
            "#D1274B",
            '#35477D',
            "#cd5c5c",
            "#FB9E91",    
            ]

polya = ["#A43955",
         "#2C2B26",
         "#6A6B5F",
         "#738C79",
         "#ECBE13"]

ostrich = [ # turn alpha on
    "navy",
    "orangered",
    "teal",
    "midnightblue",
    '#d45d79',
    ]

fraiche = ['#472b62',
           "#f5f0e3",
          '#bc4873',
           "#222222",
           '#fb5b5a',
      ]

cheshire=['#730068',
         '#347474',
         '#470938',
         '#1a3e59',
         '#b21f66',
         '#111d5e',]

carmine = [
    'maroon',
    "#f0f0f0",
    "#222222",
    'lightcoral',
    'indianred',
    'firebrick',
    ]



joan = ['#166161', 
        '#0e3244', 
        '#c4ad75', 
        '#e3dac5', 
        '#0a152e']


pinot = ['#9e1b3e', 
         '#bdc9a9', 
         '#908474', 
         '#613d4c', 
         '#27162f']

addams = ['#9faeb2', 
          '#ab6e7d', 
          '#1c2630']


minuit = ['#180d56', 
          '#282985', 
          '#3c9496', 
          '#e36d25', 
          '#98133c',
          '#d85156']


fugazi = ['#000208', 
          '#a49b87', 
          '#ece6d3', 
          '#04133f', 
          '#ca4138']


clementine = ['#fa4c49', 
              '#faf5d7', 
              '#37848e', 
              '#faa851', 
              '#0b2a45', 
              '#0d0432']


leda=['#2c2f30', 
      '#8fa7d7', 
      '#afd7d6', 
      '#aa3751', 
      '#f5b3b8']

pugsley = ['#eadca3', 
           '#679181', 
           '#450301', 
           '#911501', 
           '#07093e']


bellhooks = ['#100a0b', 
             '#facab6', 
             '#b38577', 
             '#d66f31', 
             '#2e211f']


wes = ['#d7adad', 
       '#94afbf', 
       '#1c2630', 
       '#aa352e', 
       '#6b7b75', 
       '#4a4634',
      ]


lysergic = ['#4d53b5',
        '#011b5a',
        '#238cb5', 
        '#75bcbd', 
        '#b92c60']


pepo = ['#29937b',
             '#044032',
             '#902a42',
             '#3f0914',
             '#e4607c']

==> chromatose-0.0.2.tar.gz: chromatose-0.0.2/chromatose/palettes.py <==

selah = ['#405950',
         '#3e242f',
         '#7d4246',
         '#e06865',
         '#f3ad78']

frieda = ['#e6472c',
           '#eed9a1',
           '#93b8b2',
           '#3d2314',
           '#ecd8ae',
           '#35443c']

honeycombe = ['#ce554e',
            '#e29f2d',
            '#a6a78c',
            '#40312b',
            '#e5c794',]

crepuscule = ['#3c8588',
             '#4d3d31',
             '#c5572e',
             '#dbad4e',
             '#efedce',]

juniper = ['#b1516a',
            '#af9c85',
            '#bbc9a2',
            '#ebd5a2',
            '#595353']

plath = ['#30343f',
           '#a84b43',
           '#d6b7b5',
           '#30343f']

blonde = ['#edb1a3',
          '#d6543a',
          '#c4bae2',
          '#3c4ebf',
          '#40ada6',
          '#e3a600']

leather = ["#d3772b",
            "#f9edcc", 
            "#c32307", 
            "#483d8b", 
            "#7d939a",
          ]

gucci = ['#e8b789', 
         '#046a50', 
         '#ddb65f', 
         '#26183a', 
         '#e81f05']

sandbar = ['#000000', 
         '#a1d9da', 
         '#d1923f', 
         '#025e8f', 
         '#e9c5a5']

fiestaware = ['#ab0b11', 
              '#e27a00', 
              '#36a3c2', 
              '#dfcd00', 
              '#5a006e']

chilaquiles = ['#749e81', 
               '#821b07', 
               '#01300d', 
               '#d3af03']

eleven = ['#c65f25', 
          '#4c0c0a', 
          '#fc5659', 
          '#efb36e', 
          '#6487cc']

splenda = ['#6487cc', 
           '#d49a8e', 
           '#c0c7f6', 
           '#e396bd']

gremlin = ['#3a5b84', 
           '#9d2020', 
           '#2b2b2b', 
           '#836a00', 
           '#002c59']

pollen = ["#fB9e91",
          "#461a84",
          "#f5f0e3",
          "#b4b6d8",
          '#ffd082',
#         '#9dab86',
         ]

medium = ['#e3a201', 
          '#6762ab', 
          '#d55101', 
          '#0d936a']

juniper = [ "#216583",
            '#6C567B',
            "#D1274B",
            '#35477D',
            "#cd5c5c",
            "#FB9E91",    
            ]

polya = ["#A43955",
         "#2C2B26",
         "#6A6B5F",
         "#738C79",
         "#ECBE13"]

ostrich = [ # turn alpha on
    "navy",
    "orangered",
    "teal",
    "midnightblue",
    '#d45d79',
    ]

fraiche = ['#472b62',
           "#f5f0e3",
          '#bc4873',
           "#222222",
           '#fb5b5a',
      ]

cheshire=['#730068',
         '#347474',
         '#470938',
         '#1a3e59',
         '#b21f66',
         '#111d5e',]

carmine = [
    'maroon',
    "#f0f0f0",
    "#222222",
    'lightcoral',
    'indianred',
    'firebrick',
    ]

joan = ['#166161', 
        '#0e3244', 
        '#c4ad75', 
        '#e3dac5', 
        '#0a152e']

pinot = ['#9e1b3e', 
         '#bdc9a9', 
         '#908474', 
         '#613d4c', 
         '#27162f']

addams = ['#9faeb2', 
          '#ab6e7d', 
          '#1c2630']

minuit = ['#180d56', 
          '#282985', 
          '#3c9496', 
          '#e36d25', 
          '#98133c',
          '#d85156']

fugazi = ['#000208', 
          '#a49b87', 
          '#ece6d3', 
          '#04133f', 
          '#ca4138']

clementine = ['#fa4c49', 
              '#faf5d7', 
              '#37848e', 
              '#faa851', 
              '#0b2a45', 
              '#0d0432']

leda=['#2c2f30', 
      '#8fa7d7', 
      '#afd7d6', 
      '#aa3751', 
      '#f5b3b8']

pugsley = ['#eadca3', 
           '#679181', 
           '#450301', 
           '#911501', 
           '#07093e']

bellhooks = ['#100a0b', 
             '#facab6', 
             '#b38577', 
             '#d66f31', 
             '#2e211f']

wes = ['#d7adad', 
       '#94afbf', 
       '#1c2630', 
       '#aa352e', 
       '#6b7b75', 
       '#4a4634',
      ]

lysergic = ['#4d53b5',
        '#011b5a',
        '#238cb5', 
        '#75bcbd', 
        '#b92c60']

pepo = ['#29937b',
             '#044032',
             '#902a42',
             '#3f0914',
             '#e4607c']

reese =["#300a19",
        "#d89f21",
        "#a94434",
        "#bc6333",
        "#d896b0",]

lufte = ["#9fc0c1",
         "#eba8b5",
         "#65042d",
         "#714c36"]

oolong = ['#977500', 
          '#f9f2c1', 
          '#ffc670', 
          '#bf033f', 
          '#ae3f03', 
          '#896056']

pitaya = ["#cb4f70",
          "#1b718c",
          "#779e1a",
          "#f49044"]

alice = ["#52357b",
        "#301b4f",
        "#b03653",
        "#966da1",]

neko = ['#b85e00',
        '#f59994',
        "#c0b490",
        "#0d2b52"]

belle = [ "#b8131a", 
         "#ffb82b", 
         "#dd0336", 
         "#e9d1a5", 
         "#792159" ]

spiff = ["#46308d",
         "#2ea58e",
         "#e97d86",
         "#7e92bd"]

yoshi = ["#111129", 
         "#228dc3", 
         "#cd355c",
         "#d0e44e"]

phoebe = ["#f71237",
          "#1c0517",
          "#8ba794",
          "#fe5f8e",
          "#fde4d1",
          "#991a40",
          "#eeecec",
         ]

pam = ["#634131",
       "#448168",
       "#d0726f",
       "#5e7235",
       "#e1d281"]

menthol = ["#f40505",
           "#c8eaea",
           "#020437",
           "#e4ebe9",
           "#f7bc25"]

dwight = [(135, 36, 36),
            '#9dab86',
            (193,142, 142),
            (216, 180,180)
         ]

riley = ['#66c2a5', 
         '#fc8d62', 
         '#8da0cb', 
         '#e78ac3',
         '#a6d854']

mona = ['#9a1024',
        '#d14f1e',
        "#f6e5d1",
        "#819d66",
        "#4f1c36"]

eeyore = ["#6d93b3",
          "#eba516",
          "#de9586",
          "#8bb046"]

rainbow = ['#c21019',
           '#f56327',
           "#fab01d",
           '#026f69',
           '#750a2b']

all_palettes = ["selah",
                "frieda",
                "honeycombe",
                "crepuscule",
                "juniper",
                "plath",
                "blonde",
                "leather",
                "gucci",
                "sandbar",
                "fiestaware",
                "chilaquiles",
                "eleven",
                "splenda",
                "gremlin",
                "pollen",
                "medium",
                "juniper",
                "polya",
                "ostrich",
                "fraiche",
                "cheshire",
                "carmine",
                "joan",
                "pinot",
                "addams",
                "minuit",
                "fugazi",
                "clementine",
                "leda",
                "pugsley",
                "bellhooks",
                "wes",
                "lysergic",
                "pepo",]
